@@ -1,10 +1,15 @@
 package Complete::Unix;
 
+our $DATE = '2014-12-24'; # DATE
+our $VERSION = '0.02'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
+use Complete;
+
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -16,17 +21,19 @@ our @EXPORT_OK = qw(
                        complete_pid
                );
 
-our $DATE = '2014-06-29'; # DATE
-our $VERSION = '0.01'; # VERSION
-
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Unix-related completion routines',
+};
+
 $SPEC{complete_uid} = {
     v => 1.1,
     summary => 'Complete from list of Unix UID\'s',
     args => {
         word    => { schema=>[str=>{default=>''}], pos=>0 },
-        ci      => { schema=>[bool=>{default=>0}] },
+        ci      => { schema=>['bool'] },
         etc_dir => { schema=>['str*'] },
     },
     result_naked => 1,
@@ -40,13 +47,14 @@ sub complete_uid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
+    my $ci    = $args{ci} // $Complete::OPT_CI;
 
     my $res = Unix::Passwd::File::list_users(
         etc_dir=>$args{etc_dir}, detail=>1);
     return undef unless $res->[0] == 200;
-    Complete::Util::complete_array(
+    Complete::Util::complete_array_elem(
         array=>[map {$_->{uid}} @{ $res->[2] }],
-                word=>$args{word}, ci=>$args{ci});
+                word=>$args{word}, ci=>$ci);
 }
 
 $SPEC{complete_user} = {
@@ -54,7 +62,7 @@ $SPEC{complete_user} = {
     summary => 'Complete from list of Unix users',
     args => {
         word    => { schema=>[str=>{default=>''}], pos=>0 },
-        ci      => { schema=>[bool=>{default=>0}] },
+        ci      => { schema=>['bool'] },
         etc_dir => { schema=>['str*'] },
     },
     result_naked => 1,
@@ -68,13 +76,14 @@ sub complete_user {
 
     my %args  = @_;
     my $word  = $args{word} // "";
+    my $ci    = $args{ci} // $Complete::OPT_CI;
 
     my $res = Unix::Passwd::File::list_users(
         etc_dir=>$args{etc_dir}, detail=>1);
     return undef unless $res->[0] == 200;
-    Complete::Util::complete_array(
+    Complete::Util::complete_array_elem(
         array=>[map {$_->{user}} @{ $res->[2] }],
-                word=>$args{word}, ci=>$args{ci});
+                word=>$args{word}, ci=>$ci);
 }
 
 $SPEC{complete_gid} = {
@@ -82,7 +91,7 @@ $SPEC{complete_gid} = {
     summary => 'Complete from list of Unix GID\'s',
     args => {
         word    => { schema=>[str=>{default=>''}], pos=>0 },
-        ci      => { schema=>[bool=>{default=>0}] },
+        ci      => { schema=>['bool'] },
         etc_dir => { schema=>['str*'] },
     },
     result_naked => 1,
@@ -96,13 +105,14 @@ sub complete_gid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
+    my $ci    = $args{ci} // $Complete::OPT_CI;
 
     my $res = Unix::Passwd::File::list_groups(
         etc_dir=>$args{etc_dir}, detail=>1);
     return undef unless $res->[0] == 200;
-    Complete::Util::complete_array(
+    Complete::Util::complete_array_elem(
         array=>[map {$_->{gid}} @{ $res->[2] }],
-                word=>$args{word}, ci=>$args{ci});
+                word=>$args{word}, ci=>$ci);
 }
 
 $SPEC{complete_group} = {
@@ -110,7 +120,7 @@ $SPEC{complete_group} = {
     summary => 'Complete from list of Unix groups',
     args => {
         word    => { schema=>[str=>{default=>''}], pos=>0 },
-        ci      => { schema=>[bool=>{default=>0}] },
+        ci      => { schema=>['bool'] },
         etc_dir => { schema=>['str*'] },
     },
     result_naked => 1,
@@ -124,13 +134,14 @@ sub complete_group {
 
     my %args  = @_;
     my $word  = $args{word} // "";
+    my $ci    = $args{ci} // $Complete::OPT_CI;
 
     my $res = Unix::Passwd::File::list_groups(
         etc_dir=>$args{etc_dir}, detail=>1);
     return undef unless $res->[0] == 200;
-    Complete::Util::complete_array(
+    Complete::Util::complete_array_elem(
         array=>[map {$_->{group}} @{ $res->[2] }],
-                word=>$args{word}, ci=>$args{ci});
+                word=>$args{word}, ci=>$ci);
 }
 
 $SPEC{complete_pid} = {
@@ -138,7 +149,7 @@ $SPEC{complete_pid} = {
     summary => 'Complete from list of running PIDs',
     args => {
         word    => { schema=>[str=>{default=>''}], pos=>0 },
-        ci      => { schema=>[bool=>{default=>0}] },
+        ci      => { schema=>['bool'] },
     },
     result_naked => 1,
     result => {
@@ -153,11 +164,12 @@ sub complete_pid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
+    my $ci    = $args{ci} // $Complete::OPT_CI;
 
     my $procs = $pt->table;
-    Complete::Util::complete_array(
+    Complete::Util::complete_array_elem(
         array=>[map {$_->{pid}} @$procs],
-                word=>$args{word}, ci=>$args{ci});
+                word=>$args{word}, ci=>$ci);
 }
 
 1;
@@ -175,7 +187,7 @@ Complete::Unix - Unix-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.01 of Complete::Unix (from Perl distribution Complete-Unix), released on 2014-06-29.
+This document describes version 0.02 of Complete::Unix (from Perl distribution Complete-Unix), released on 2014-12-24.
 
 =head1 DESCRIPTION
 
@@ -190,7 +202,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool> (default: 0)
+=item * B<ci> => I<bool>
 
 =item * B<etc_dir> => I<str>
 
@@ -200,6 +212,8 @@ Arguments ('*' denotes required arguments):
 
 Return value:
 
+ (array)
+
 
 =head2 complete_group(%args) -> array
 
@@ -209,7 +223,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool> (default: 0)
+=item * B<ci> => I<bool>
 
 =item * B<etc_dir> => I<str>
 
@@ -219,6 +233,8 @@ Arguments ('*' denotes required arguments):
 
 Return value:
 
+ (array)
+
 
 =head2 complete_pid(%args) -> array
 
@@ -228,7 +244,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool> (default: 0)
+=item * B<ci> => I<bool>
 
 =item * B<word> => I<str> (default: "")
 
@@ -236,6 +252,8 @@ Arguments ('*' denotes required arguments):
 
 Return value:
 
+ (array)
+
 
 =head2 complete_uid(%args) -> array
 
@@ -245,7 +263,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool> (default: 0)
+=item * B<ci> => I<bool>
 
 =item * B<etc_dir> => I<str>
 
@@ -255,6 +273,8 @@ Arguments ('*' denotes required arguments):
 
 Return value:
 
+ (array)
+
 
 =head2 complete_user(%args) -> array
 
@@ -264,7 +284,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool> (default: 0)
+=item * B<ci> => I<bool>
 
 =item * B<etc_dir> => I<str>
 
@@ -274,6 +294,8 @@ Arguments ('*' denotes required arguments):
 
 Return value:
 
+ (array)
+
 =head1 SEE ALSO
 
 L<Complete::Util>
@@ -284,7 +306,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Complete-Unix>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Unix>.
 
 =head1 BUGS
 
@@ -296,11 +318,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
